@@ -13,18 +13,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gio
-from gi.repository import GObject
-from gi.repository import Pango
-from gi.repository import GtkSource
+import sys
+
+from gi.repository import Gio, GObject, Gtk, GtkSource, Pango
 
 import meld.conf
 import meld.filters
 
 
-MELD_SCHEMA = 'org.gnome.meld'
-
-
 class MeldSettings(GObject.GObject):
     """Handler for settings that can't easily be bound to object properties"""
 
@@ -35,10 +31,11 @@ class MeldSettings(GObject.GObject):
     }
 
     def __init__(self):
-        GObject.GObject.__init__(self)
+        super().__init__()
         self.on_setting_changed(settings, 'filename-filters')
         self.on_setting_changed(settings, 'text-filters')
         self.on_setting_changed(settings, 'use-system-font')
+        self.on_setting_changed(settings, 'prefer-dark-theme')
         self.style_scheme = self._style_scheme_from_gsettings()
         settings.connect('changed', self.on_setting_changed)
 
@@ -54,13 +51,20 @@ class MeldSettings(GObject.GObject):
         elif key in ('use-system-font', 'custom-font'):
             self.font = self._current_font_from_gsetting()
             self.emit('changed', 'font')
+        elif key == 'prefer-dark-theme':
+            gtk_settings = Gtk.Settings.get_default()
+            prefer_dark = settings.get_boolean(key)
+            gtk_settings.props.gtk_application_prefer_dark_theme = prefer_dark
         elif key in ('style-scheme'):
             self.style_scheme = self._style_scheme_from_gsettings()
             self.emit('changed', 'style-scheme')
 
     def _style_scheme_from_gsettings(self):
+        from meld.style import set_base_style_scheme
         manager = GtkSource.StyleSchemeManager.get_default()
-        return manager.get_scheme(settings.get_string('style-scheme'))
+        scheme = manager.get_scheme(settings.get_string('style-scheme'))
+        set_base_style_scheme(scheme)
+        return scheme
 
     def _filters_from_gsetting(self, key, filt_type):
         filter_params = settings.get_value(key)
@@ -72,16 +76,20 @@ class MeldSettings(GObject.GObject):
 
     def _current_font_from_gsetting(self, *args):
         if settings.get_boolean('use-system-font'):
-            font_string = interface_settings.get_string('monospace-font-name')
+            if sys.platform == 'win32':
+                font_string = 'Consolas 11'
+            else:
+                font_string = interface_settings.get_string(
+                    'monospace-font-name')
         else:
             font_string = settings.get_string('custom-font')
         return Pango.FontDescription(font_string)
 
 
 def load_settings_schema(schema_id):
-    if meld.conf.UNINSTALLED_SCHEMA:
+    if meld.conf.DATADIR_IS_UNINSTALLED:
         schema_source = Gio.SettingsSchemaSource.new_from_directory(
-            meld.conf.DATADIR,
+            str(meld.conf.DATADIR),
             Gio.SettingsSchemaSource.get_default(),
             False,
         )
@@ -94,11 +102,11 @@ def load_settings_schema(schema_id):
 
 
 def create_settings():
-    global settings, interface_settings, meldsettings
+    global settings, interface_settings, _meldsettings
 
-    settings = load_settings_schema(MELD_SCHEMA)
+    settings = load_settings_schema(meld.conf.SETTINGS_SCHEMA_ID)
     interface_settings = Gio.Settings.new('org.gnome.desktop.interface')
-    meldsettings = MeldSettings()
+    _meldsettings = MeldSettings()
 
 
 def bind_settings(obj):
@@ -109,7 +117,17 @@ def bind_settings(obj):
         settings_id, property_id = binding
         settings.bind(settings_id, obj, property_id, bind_flags)
 
+    bind_flags = (
+        Gio.SettingsBindFlags.GET | Gio.SettingsBindFlags.NO_SENSITIVITY)
+    for binding in getattr(obj, '__gsettings_bindings_view__', ()):
+        settings_id, property_id = binding
+        settings.bind(settings_id, obj, property_id, bind_flags)
+
+
+def get_meld_settings() -> MeldSettings:
+    return _meldsettings
+
 
 settings = None
 interface_settings = None
-meldsettings = None
+_meldsettings = None
